#
# spec file for package python-Flask-Security-Too
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Flask-Security-Too
Version:        3.4.2
Release:        1.6
Summary:        Security for Flask apps
License:        MIT
URL:            https://github.com/jwag956/flask-security
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Security-Too/Flask-Security-Too-%{version}.tar.gz
Patch0:         no-mongodb.patch
Patch1:         no-setup-dependencies.patch
Patch2:         fix-dependencies.patch
BuildRequires:  %{python_module Babel >= 1.3}
BuildRequires:  %{python_module Flask >= 1.0.2}
BuildRequires:  %{python_module Flask-BabelEx >= 0.9.3}
BuildRequires:  %{python_module Flask-Login >= 0.4.1}
BuildRequires:  %{python_module Flask-Mail >= 0.9.1}
BuildRequires:  %{python_module Flask-Principal >= 0.4.0}
BuildRequires:  %{python_module Flask-SQLAlchemy >= 2.3}
BuildRequires:  %{python_module Flask-WTF >= 0.14.2}
BuildRequires:  %{python_module PyQRCode >= 1.2}
BuildRequires:  %{python_module SQLAlchemy >= 1.2.6}
BuildRequires:  %{python_module Werkzeug >= 0.14.1}
BuildRequires:  %{python_module argon2_cffi >= 19.1.0}
BuildRequires:  %{python_module bcrypt >= 3.1.4}
BuildRequires:  %{python_module cachetools >= 3.1.0}
BuildRequires:  %{python_module cryptography >= 2.1.4}
BuildRequires:  %{python_module email_validator >= 1.0.5}
BuildRequires:  %{python_module itsdangerous >= 1.1.0}
BuildRequires:  %{python_module mock >= 1.3.0}
BuildRequires:  %{python_module passlib >= 1.7.1}
BuildRequires:  %{python_module peewee >= 3.7.1}
BuildRequires:  %{python_module phonenumbers >= 8.11.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zxcvbn >= 4.4.28}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 1.0.2
Requires:       python-Flask-BabelEx >= 0.9.3
Requires:       python-Flask-Login >= 0.4.1
Requires:       python-Flask-Mail >= 0.9.1
Requires:       python-Flask-Principal >= 0.4.0
Requires:       python-Flask-WTF >= 0.14.2
Requires:       python-Werkzeug >= 0.14.1
Requires:       python-bcrypt >= 3.1.4
Requires:       python-cryptography >= 2.1.4
Requires:       python-email_validator >= 1.0.5
Requires:       python-itsdangerous >= 1.1.0
Requires:       python-passlib >= 1.7.1
Recommends:     python-PyQRCode >= 1.2
Recommends:     python-SQLAlchemy >= 1.2.6
Recommends:     python-zxcvbn >= 4.4.28
Suggests:       python-argon2_cffi >= 19.1.0
Suggests:       python-phonenumbers >= 8.11.1
Conflicts:      python-Flask-Security < 3.2.0
Obsoletes:      python-Flask-Security < 3.2.0
Provides:       python-Flask-Security = %{version}
BuildArch:      noarch
%python_subpackages

%description
Flask-Security-Too is a Python module to add security features to a Flask
application. This is a independently maintained version of Flask-Security
based on the 3.0.0 version of the original.

%prep
%setup -q -n Flask-Security-Too-%{version}
%autopatch -p1
rm pytest.ini

%if 0%{?suse_version} <= 1500
# test_trackable.py needs werkzeug.middleware.proxy_fix which is only available
# in newer werkzeug versions
rm tests/test_trackable.py
%endif

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/flask_security
%{python_sitelib}/Flask_Security_Too-%{version}-py%{python_version}.egg-info

%changelog
* Thu May 14 2020 alarrosa@suse.com
- Decrease dependencies which aren't really required so we can build
  in SLE/Leap:
  * Werkzeug 0.15.5 requirement decreased to 0.14.1
  * cryptography 2.3.1 requirement decreased to 2.1.4
  * bcrypt 3.1.5 requirement decreased to 3.1.4
  * peewee 3.11.2 requirement decreased to 3.7.1
  * Remove python-pony requirement
- Add patch that applies previous dependency changes:
  * fix-dependencies.patch
* Thu May 14 2020 tchvatal@suse.com
- Add patch to not pull in babel/twine/pytest-runner as
  upstream needs those but we really don't require them during
  a rpm build:
  * no-setup-dependencies.patch
* Thu May  7 2020 alarrosa@suse.com
- Update to 3.4.2:
  * The flask-security repo was moved to a github organization
    Flask-Middleware.
- Update to 3.4.1:
  * Fix a bunch of bugs in new unified sign in along with a couple
    other major issues.
  * (:issue:`298`) Alternative ID feature ran afoul of
    postgres/psycopg2 finickiness.
  * (:issue:`300`) JSON 401 responses had WWW-Authenticate Header
    attached - that caused browsers to pop up their own login/password
    form. Not what applications want.
  * (:issue:`280`) Allow admin/api to setup TFA (and unified sign in)
    out of band. Please see :meth:`.UserDatastore.tf_set`,
    :meth:`.UserDatastore.tf_reset`, :meth:`.UserDatastore.us_set`,
    :meth:`.UserDatastore.us_reset` and
    :meth:`.UserDatastore.reset_user_access`.
  * (:pr:`305`) We used form._errors which wasn't very pythonic,
    and it was removed in WTForms 2.3.0.
  * (:pr:`310`) WTForms 2.3.0 made email_validator optional,
    we need it.
- Added Requires python-bcrypt and python-email_validator,
  Recommends python-PyQRCode, python-SQLAlchemy, python-zxcvbn
  and Suggests python-argon2_cffi and python-phonenumbers
* Sun Apr  5 2020 tchvatal@suse.com
- Update to 3.4.0:
  * (:pr:`257`) Support a unified sign in feature.
    Please see :ref:`unified-sign-in`.
  * (:pr:`265`) Add phone number validation class. This is used in
    both unified sign in as well as two-factor when using sms.
  * (:pr:`274`) Add support for 'freshness' of caller's authentication.
    This permits endpoints to be additionally protected by ensuring a
    recent authentication.
  * (:issue:`99`, :issue:`195`) Support pluggable password validators.
    Provide a default validator that offers complexity and breached support.
  * (:issue:`266`) Provide interface to two-factor send_token so that
    applications can provide error mitigation. Defaults to returning
    errors if can't send the verification code.
  * (:pr:`247`) Updated all-inclusive data models (fsqlaV2). Add
    fields necessary for the new unified sign in feature and changed
    'username' to be unique (but not required).
  * (:pr:`245`) Use fs_uniquifier as the default Flask-Login
    'alternative token'. Basically this means that changing the
    fs_uniquifier will cause outstanding auth tokens, session and
    remember me cookies to be invalidated. So if an account gets
    compromised, an admin can easily stop access. Prior to this cookies
    were storing the 'id' which is the user's primary key - difficult
    to change! (kishi85)
- Enable the testing
- Add patch to not require mongodb during testing:
  * no-mongodb.patch
* Tue Mar 24 2020 alarrosa@suse.com
- Initial release of python-Flask-Security-Too 3.3.0
